@@ -5,14 +5,24 @@ from ._version import get_versions
 __version__ = get_versions()["version"]
 del get_versions
 
-__all__ = ["insert", "exists", "SelectStatementBuilder"]
+__all__ = [
+    "require_table",
+    "insert",
+    "exists",
+    "SelectStatementBuilder",
+    "update",
+    "delete",
+]
 
 # Standard library modules.
 
 # Third party modules.
 
 # Local modules.
+from .base import require_table
 from .insert import insert, exists
 from .select import SelectStatementBuilder
+from .update import update
+from .delete import delete
 
 # Globals and constants variables.
